@@ -85,12 +85,9 @@ class InstalledPane(SoftwarePane):
                                         self.on_navigation_list,
                                         "list",
                                         animate=False)
-        # *ugh* deactivate the old model because otherwise it keeps
-        # getting progress_changed events and eats CPU time until it's
-        # garbage collected
-        old_model = self.app_view.get_model()
-        if old_model is not None:
-            old_model.active = False
+        # deactivate the old model, otherwise we have a memleak and
+        # a cpu leak
+        self.app_view.clear_model()
         # get a new store and attach it to the view
         new_model = AppStore(self.cache,
                              self.db, 
